DCFPortal class

A portal component that renders its children into a different part of the component tree

Inheritance

Constructors

DCFPortal({String? key, required String targetId, required List<DCFComponentNode> children, bool createTarget = false, dynamic onPortalMount(String targetId)?, dynamic onPortalUnmount(String targetId)?})

Properties

children List<DCFComponentNode>
Children to be portaled
final
contentViewId String?
The native view ID of the rendered content
getter/setter pairinherited
createTarget bool
Whether to create the target if it doesn't exist
final
effectiveNativeViewId String?
Get effective native view ID (may be from rendered content)
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
instanceId String
Unique ID for this component instance
finalinherited
isMounted bool
Get whether the component is mounted
no setterinherited
key String?
Unique identifier for this node
finalinherited
nativeViewId String?
Native view ID once rendered
getter/setter pairinherited
onPortalMount → dynamic Function(String targetId)?
Optional callback when portal is mounted
final
onPortalUnmount → dynamic Function(String targetId)?
Optional callback when portal is unmounted
final
parent DCFComponentNode?
Parent node in the virtual tree
getter/setter pairinherited
renderedNode DCFComponentNode
Get the rendered node (lazily render if necessary)
getter/setter pairinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
scheduleUpdate ↔ dynamic Function()
Function to schedule updates when state changes
getter/setter pairinherited
targetId String
The target container ID where children will be portaled
final
typeName String
Type name for debugging
finalinherited

Methods

clone() DCFComponentNode
Implement VDomNode methods
inherited
componentDidMount() → void
Called when the component is mounted
override
componentDidUpdate(Map<String, dynamic> prevProps) → void
Called after the component updates
override
componentWillUnmount() → void
Called when the component will unmount
override
equals(DCFComponentNode other) bool
Whether this node is equal to another
inherited
mount(DCFComponentNode? parent) → void
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
prepareForRender() → void
Reset hook state for next render
inherited
render() DCFComponentNode
Render the component - must be implemented by subclasses
override
runEffectsAfterRender() → void
Run effects after render - called by VDOM
inherited
toString() String
A string representation of this object.
inherited
unmount() → void
inherited
useEffect(dynamic Function()? effect(), {List dependencies = const []}) → void
Create an effect hook
inherited
useRef<T>([T? initialValue]) RefObject<T>
Create a ref hook
inherited
useState<T>(T initialValue, [String? name]) StateHook<T>
Create a state hook
inherited
useStore<T>(Store<T> store) StoreHook<T>
Create a store hook for global state
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited